package com.ruoyi.project.patrol.dev.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.patrol.dev.mapper.TDevSandboxMapper;
import com.ruoyi.project.patrol.dev.domain.TDevSandbox;
import com.ruoyi.project.patrol.dev.service.ITDevSandboxService;

/**
 * 应急沙箱Service业务层处理
 * 
 * @author admin
 * @date 2023-11-02
 */
@Service
public class TDevSandboxServiceImpl implements ITDevSandboxService 
{
    @Autowired
    private TDevSandboxMapper tDevSandboxMapper;

    /**
     * 查询应急沙箱
     * 
     * @param id 应急沙箱主键
     * @return 应急沙箱
     */
    @Override
    public TDevSandbox selectTDevSandboxById(Long id)
    {
        return tDevSandboxMapper.selectTDevSandboxById(id);
    }

    /**
     * 查询应急沙箱列表
     * 
     * @param tDevSandbox 应急沙箱
     * @return 应急沙箱
     */
    @Override
    public List<TDevSandbox> selectTDevSandboxList(TDevSandbox tDevSandbox)
    {
        return tDevSandboxMapper.selectTDevSandboxList(tDevSandbox);
    }

    /**
     * 新增应急沙箱
     * 
     * @param tDevSandbox 应急沙箱
     * @return 结果
     */
    @Override
    public int insertTDevSandbox(TDevSandbox tDevSandbox)
    {
        return tDevSandboxMapper.insertTDevSandbox(tDevSandbox);
    }

    /**
     * 修改应急沙箱
     * 
     * @param tDevSandbox 应急沙箱
     * @return 结果
     */
    @Override
    public int updateTDevSandbox(TDevSandbox tDevSandbox)
    {
        return tDevSandboxMapper.updateTDevSandbox(tDevSandbox);
    }

    /**
     * 批量删除应急沙箱
     * 
     * @param ids 需要删除的应急沙箱主键
     * @return 结果
     */
    @Override
    public int deleteTDevSandboxByIds(Long[] ids)
    {
        return tDevSandboxMapper.deleteTDevSandboxByIds(ids);
    }

    /**
     * 删除应急沙箱信息
     * 
     * @param id 应急沙箱主键
     * @return 结果
     */
    @Override
    public int deleteTDevSandboxById(Long id)
    {
        return tDevSandboxMapper.deleteTDevSandboxById(id);
    }
}
